@@ -245,11 +245,12 @@ gpointer  sunone_connection_get_wcap (SunOneConnection *connection, const char *
 guint		  sunone_connection_version (SunOneConnection *connection);
 const char *sunone_connection_get_user (SunOneConnection *connection);
 void		sunone_connection_set_user (SunOneConnection *connection, const char *user);
+const char *sunone_connection_get_uid (SunOneConnection *connection);
 const char *sunone_connection_get_wcap_version (SunOneConnection *connection);
 void		sunone_connection_set_wcap_version (SunOneConnection *connection, const char *wcap_version);
 
-SoupStatusClass  sunone_message_send (SunOneConnection *cnc, SoupMessage *msg);
-SoupStatusClass  sunone_message_send_no_parse (SunOneConnection *cnc, SoupMessage *msg);
+guint  sunone_message_send (SunOneConnection *cnc, SoupMessage *msg);
+guint  sunone_message_send_no_parse (SunOneConnection *cnc, SoupMessage *msg);
 
 G_END_DECLS
 
