@@ -514,7 +514,7 @@ sunone_subscription_dialog_new (SunOneFolderTree *tree, SunOneConnection *cnc)
 	gtk_window_set_title (GTK_WINDOW (dialog), _("Remote Calendar Subscriptions"));
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog), GTK_STOCK_OK, GTK_RESPONSE_OK, GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, NULL); 
 	gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, FALSE);
-	gtk_widget_set_size_request (GTK_WIDGET (dialog), 600, 400);
+	gtk_widget_set_size_request (GTK_WIDGET (dialog), -1, 400);
 
 	g_signal_connect (dialog, "response",
 			    G_CALLBACK (dialog_button_clicked_cb), NULL);
